import os
from flask import Flask, render_template
from flask_sqlalchemy import SQLAlchemy
from flask_cors import CORS


db = SQLAlchemy()

class CustomFlask(Flask):
    jinja_options = Flask.jinja_options.copy()
    jinja_options.update(dict(
        variable_start_string='[[', 
        variable_end_string=']]', 
        ))

def create_app():

    text_component = {"project_name": "LabelsTower", 
                      "Element_name": "Element(s)", 
                      "Label": "Label(s)"
                      }
    app = CustomFlask(__name__)
    CORS(app)
    db.init_app(app)

    app.config.from_object(os.environ['LABELSTOWER_ENV'])

    from app.labels_system import bp
    app.register_blueprint(bp, url_prefix='/sort')

    @app.route('/')
    @app.route('/browse')
    def home():
        return render_template('browse.html', txt=text_component)
    return app



